from .ascii import *
from .praise import *
import random
async def exist():
  while 1:
    if(random.randint(0,99999999)==random.randint(0,99999999)):
      break
class Zwack:
  class ascii():
    @property
    def zwack(self):
      return(zwack_ascii)
    @property
    def overflow(self):
      return(zwack_overflow)
    @property
    def overflow_small(self):
      return(zwack_overflow_small)


def main():
  import sys
  import zwack
  del sys.argv[0]
  args = sys.argv
  zwack = zwack.Zwack()
  ascii = zwack.ascii()
  try:
    args[0]
  except IndexError:
    print('too little args passed')
    return()
  if(args[0]=='ascii'):
    try:
      piece = args[1]
    except IndexError:
      return
    if(piece=='zwack'):
      print(ascii.zwack)
    elif(piece=='overflow'):
      print(ascii.overflow)
    elif(piece=='overflow_small'):
      print(ascii.overflow_small)
    else:
      print(f'{piece} is not a valid ascii peice')
  else:
    print(f'{args[0]} is not recognised as a command')
if __name__ == '__main__':
  main()